@@ -443,6 +443,15 @@ def convert(string):
     open_paragraph = False
 
     def convert_paragraph(line):
+        """
+        Convert a line into a paragraph.
+
+        Args:
+            line (str): Line to convert.
+
+        Returns:
+            str: Converted line.
+        """
         nonlocal open_paragraph
         if not open_paragraph:
             open_paragraph = True
@@ -496,7 +505,8 @@ def convert(string):
                 if tag["regex"].fullmatch(line):
                     new_line = convert_nested_tag(line, tag, open_tags)
 
-        # If not, check if there are open tags, if so, close them.
+        # If not, check if there are open tags, if so, close them. After doing
+        # so, check whether the line is a paragraph and add it accordingly.
         elif open_tags:
             for tag in reversed(open_tags):
                 new_line += tag[0]["outer_closing_tag"]
